@@ -199,7 +199,7 @@ class CorrelateAction(base.Action):
         if xyz is None:
             return
 
-        data = ovl.nibImage.get_data()[opts.index(atVolume=False)]
+        data = ovl.data[opts.index(atVolume=False)]
 
         # The correlation calculation is performed
         # on a separate thread. This thread then
